@@ -1,20 +1,7 @@
 /*
- * Copyright (C) 2017~2017 by CSSlayer
- * wengxt@gmail.com
+ * SPDX-FileCopyrightText: 2017-2017 CSSlayer <wengxt@gmail.com>
  *
- * This library is free software; you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of the
- * License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; see the file COPYING. If not,
- * see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #ifndef _FCITX_LIBIME_PINYIN_SHUANGPINPROFILE_H_
 #define _FCITX_LIBIME_PINYIN_SHUANGPINPROFILE_H_
@@ -56,6 +43,7 @@ public:
 
     const TableType &table() const;
     const ValidInputSetType &validInput() const;
+    const ValidInputSetType &validInitial() const;
 
 private:
     void buildShuangpinTable();
